@@ -36,7 +36,7 @@ no warnings;
 
 @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.41._0'; # our $VERSION = '';
+$VERSION = '0.43.0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -75,8 +75,8 @@ sub retrieve
 	
 	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
-	say "\nNow in Sim::OPT::Report.\n";
-	say TOSHELL "\n#Now in Sim::OPT::Report.\n";
+	say "\nNow in Sim::OPT::Report::retrieve.\n";
+	say TOSHELL "\n#Now in Sim::OPT::Report_retrieve.\n";
 	
 	%dowhat = %main::dowhat;
 
@@ -91,12 +91,13 @@ sub retrieve
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	$reportdata = $main::reportdata;
+	$reportdata = $main::reportdata; say TOSHELL "dump(\$reportdata): " . dump($reportdata);
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
 	@maketabledata = @main::maketabledata;
 	@filter_columns = @main::filter_columns;
+	%vals = %main::vals;
 	
 	my @simcases = @{ $dirfiles{simcases} }; say TOSHELL "dump(\@simcases): " . dump(@simcases);
 	my @simstruct = @{ $dirfiles{simstruct} }; say TOSHELL "dump(\@simstruct): " . dump(@simstruct);
@@ -122,6 +123,9 @@ sub retrieve
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
+	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);	
 	my %notecases;
 	
 	#my $getpars = shift;
@@ -145,6 +149,8 @@ sub retrieve
 		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
+		my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinreport(\$skip): " . dump($skip);
+		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
 		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
 		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
@@ -271,13 +277,14 @@ $printthis";
 		sub retrieve_stats_results
 		{	
 			my ( $result, $resfile, $retrdata_ref, $reporttitle, $theme, $counttheme, $countreport, $retfile, $semaphorego, $semaphorestop, $textpattern) = @_;
-			print TOSHELL " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \@retrievedata: @retrievedata, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
-							
-			my @retrdata = @$retrdata_ref; #say TOSHELL "\@retrdata " . dump(@retrdata);
+			print TOSHELL " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$theme: $theme, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+			print TOSHELL "\@retrievedata: " . dump( @retrievedata ); 
+			my @retrdata = @$retrdata_ref; say TOSHELL "\@retrdata " . dump(@retrdata);
+			my $printthis;
 			
 			if ( $theme eq "loads" )
 			{
-				my $printthis =
+				$printthis =
 "res -file $resfile -mode script<<TTT
 
 3
@@ -302,7 +309,7 @@ TTT
 			}
 			elsif ( $theme eq "tempsstats" )
 			{
-				my $printthis =
+				$printthis =
 "res -file $resfile -mode script<<TTT
 
 3
@@ -336,110 +343,121 @@ $printthis
 		}
 		
 		#say TOSHELL "\nNow in Sim::OPT::Retrieve. INSIDE";
-		my $resfile = $simstruct[$countcase][$countblock][$countinstance]; #$simcases[$countinstance]; ### HERE!!! ZZZ 
+		my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance] }; say TOSHELL "SAY\@resfiles " . dump(@resfiles); 
 		#say TOSHELL "SAY\@simcases " . dump(@simcases); say TOSHELL "SAY\@simstruct " . dump(@simstruct); 
 		
+		
+		say TOSHELL "\@retrievedata " . dump(@retrievedata);
 		my $counttheme = 0;
 		foreach my $retrievedatum (@retrievedata)
-		{
-			my $reportdata_ref_ref = $reportdata->[$counttheme];
-			my $retrievedatarefsdeep = $retrievedata[$counttheme];
-			my @retrievedatarefs = @{$retrievedatum};
-			my $simtitle = $simtitles[$counttheme]; #say TOSHELL "\$simtitle " . dump($simtitle);
-			my @sims = @{$simdata[$countheme]}; #say TOSHELL "\@sims " . dump(@sims);
+		{	say TOSHELL "\$retrievedatum " . dump($retrievedatum);
+			my $reportdata_ref_ref = $reportdata->[$counttheme]; say TOSHELL "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
+			my $retrievedatarefsdeep = $retrievedata[$counttheme]; say TOSHELL "\$retrievedatarefsdeep " . dump($retrievedatarefsdeep);
+			my @retrievedatarefs = @{$retrievedatum}; say TOSHELL "\@retrievedatarefs " . dump(@retrievedatarefs);
+			my $simtitle = $simtitles[$counttheme]; say TOSHELL "\$simtitle " . dump($simtitle);
+			my @sims = @{ $simdata[ $countheme ] }; say TOSHELL "\@sims " . dump(@sims);
 			
-			my $countreport = 0;
-			foreach my $retrievedataref (@retrievedatarefs)
+			my $resfile = $resfiles[ $counttheme ]; say TOSHELL "\HERE\$resfile " . dump($resfile);
+			
+			#if ( not ( eval ( $skipreport ) ) )
+			if ( -e $resfile ) 
 			{
-				my @retrdata = @$retrievedataref; #say TOSHELL "\@retrdata " . dump(@retrdata);
-				my $sim = $sims[$countreport]; #say TOSHELL "\$sim-RESFILE" . dump($sim); 
-				my $targetprov = $sim;
-				$targetprov =~ s/$mypath\///;
-				my $result = "$mypath" . "/$targetprov"; #say TOSHELL "\$result " . dump($result); 
 				
-				#if ( fileno (RETLIST) )
-				#if (not (-e $retlist ) )
-				#{
-				#	if ( $countblock == 0 )
-				#	{
-						open( RETLIST, ">>$retlist"); # or die;
-				#	}
-				#	else 
-				#	{
-				#		open( RETLIST, ">>$retlist"); # or die;
-				#	}
-				#}
-				
-				#if ( fileno (RETLIST) ) # SAME LEVEL OF RETLIST. JUST ANOTHER CONTAINER.
-				#if (not (-e $retblock ) )
-				#{
-				#	if ( $countblock == 0 )
-				#	{
-						open( RETBLOCK, ">>$retblock"); # or die;
-				#	}
-				#	else 
-				#	{
-				#		open( RETBLOCK, ">>$retblock"); # or die;
-				#	}
-				#}
-								
-				my $reportdata_ref = $reportdata_ref_ref->[$countreport];
-				my @reportdata = @$reportdata_ref;
-				
-				my $countitem = 0;
-				foreach my $item ( @reportdata )
+				my $countreport = 0;
+				foreach my $retrievedataref (@retrievedatarefs)
 				{
-					my %datarep = %$item;
-					my $reporttitle = $datarep->{reporttitle};
-					my $theme = $datarep->{themereport};
-					my $semaphorego = $datarep->{semaphorego};
-					my $semaphorestop = $datarep->{semaphorestop};
-					my $textpattern = $datarep->{textpattern};
+					say TOSHELL "\$retrievedataref " . dump($retrievedataref);
+					my @retrdata = @$retrievedataref; say TOSHELL "\@retrdata " . dump(@retrdata);
+					my $sim = $sims[$countreport]; say TOSHELL "\$sim-RESFILE" . dump($sim); 
+					my $targetprov = $sim;
+					$targetprov =~ s/$mypath\///;
+					my $result = "$mypath" . "/$targetprov"; say TOSHELL "\$result " . dump($result); 
 					
-					my $retfile = "$resfile-$reporttitle-$theme.grt";
+					#if ( fileno (RETLIST) )
+					#if (not (-e $retlist ) )
+					#{
+					#	if ( $countblock == 0 )
+					#	{
+							open( RETLIST, ">>$retlist"); # or die;
+					#	}
+					#	else 
+					#	{
+					#		open( RETLIST, ">>$retlist"); # or die;
+					#	}
+					#}
 					
-					say TOSHELL "\$retfile " . dump($retfile);
+					#if ( fileno (RETLIST) ) # SAME LEVEL OF RETLIST. JUST ANOTHER CONTAINER.
+					#if (not (-e $retblock ) )
+					#{
+					#	if ( $countblock == 0 )
+					#	{
+							open( RETBLOCK, ">>$retblock"); # or die;
+					#	}
+					#	else 
+					#	{
+					#		open( RETBLOCK, ">>$retblock"); # or die;
+					#	}
+					#}
+									
+					my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say TOSHELL "\$reportdata_ref" . dump($reportdata_ref); 
+					my @reportdata = @$reportdata_ref;  say TOSHELL "\@reportdata" . dump(@reportdata); 
 					
-					$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem] = $retfile;
-					print RETBLOCK "$retfile\n";
-					
-					if ( not ($retfile ~~ @retcases ) )
+					my $countitem = 0;
+					foreach my $item ( @reportdata )
 					{
-						push ( @retcases, $retfile );
-						say RETLIST "$retfile";
-					}
-					
-					if ( not ($retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $countinstance ] } ) )
-					{
-						$notecases[ $countcase ][ $countblock ][ $countinstance ][ $countitem ] = 
-															{
-																retfile => $retfile,
-																reporttitle => $reporttitle,
-																themereport => $themereport,
-																semaphorego => $semaphorego,
-																semaphorestop => $semaphorestop,
-																textpattern => $textpattern
-															};
-					}
-					
-					say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: going to write $retfile.\ ";
+						my %datarep = %$item; say TOSHELL "\%datarep" . dump(%datarep); 
+						my $reporttitle = $datarep{reporttitle}; say TOSHELL "\$reporttitle! " . dump($reporttitle); ###DDD HERE
+						my $theme = $datarep{themereport}; say TOSHELL "\$theme " . dump($theme); 
+						my $semaphorego = $datarep{semaphorego}; say TOSHELL "\$semaphorego " . dump($semaphorego); 
+						my $semaphorestop = $datarep{semaphorestop}; say TOSHELL "\$semaphorestop " . dump($semaphorestop); 
+						my $textpattern = $datarep{textpattern}; say TOSHELL "\$textpattern " . dump($textpattern); 
 						
-					if ( $theme eq "temps" ) 
-					{
-						 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
+						my $retfile = "$resfile-$reporttitle-$theme.grt"; say TOSHELL "\$retfile " . dump($retfile); 
+								
+						say TOSHELL "\$retfile " . dump($retfile);
+						
+						$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem] = $retfile;
+						print RETBLOCK "$retfile\n";
+						
+						if ( not ($retfile ~~ @retcases ) )
+						{
+							push ( @retcases, $retfile );
+							say RETLIST "$retfile";
+						}
+						
+						if ( not ($retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $countinstance ] } ) )
+						{
+							$notecases[ $countcase ][ $countblock ][ $countinstance ][ $countitem ] = 
+																{
+																	retfile => $retfile,
+																	reporttitle => $reporttitle,
+																	themereport => $themereport,
+																	semaphorego => $semaphorego,
+																	semaphorestop => $semaphorestop,
+																	textpattern => $textpattern
+																};
+						}
+						
+						say "#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: going to write $retfile.\ ";
+							
+						if ( $theme eq "temps" ) 
+						{
+							 retrieve_temperatures_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
+						}
+						elsif ( $theme eq "comfort"  ) 
+						{ 
+							retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
+						}
+						elsif ( ( $theme eq "loads" ) or ( $theme eq "tempsstats"  ) )
+						{ 
+							retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, 
+										$countreport, $retfile, $semaphorego, $semaphorestop, $textpattern ); 
+						}
+						$countitem++;
 					}
-					elsif ( $theme eq "comfort"  ) 
-					{ 
-						retrieve_comfort_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, $countreport, $retfile ); 
-					}
-					elsif ( ( $theme eq "loads" ) or ( $theme eq "tempsstats"  ) )
-					{ 
-						retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $theme, $counttheme, 
-									$countreport, $retfile, $semaphorego, $semaphorestop, $textpattern ); 
-					}
-					$countitem++;
+					$countreport++;
 				}
-				$countreport++;
+			
 			}
 			$counttheme++;
 		}
@@ -486,8 +504,8 @@ sub report # This function retrieves the results of interest from the texts file
 	
 	open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
-	say "\nNow again in Sim::OPT::Report::report.\n";
-	say TOSHELL "\n#Now again in Sim::OPT::Report::report.\n";
+	say "\nNow in Sim::OPT::Report::report.\n";
+	say TOSHELL "\n#Now in Sim::OPT::Report::report.\n";
 	
 	%dowhat = %main::dowhat;
 
@@ -513,21 +531,21 @@ sub report # This function retrieves the results of interest from the texts file
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
 	my @INREPORT = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
-	my @retcases = @{ $dirfiles{retcases} }; #say TOSHELL "dumpINREPORT::report(\@retcases): " . dump(@retcases); say "dumpINDESCEND(\@retcases): " . dump(@retcases);
-	my @retstruct = @{ $dirfiles{retstruct} }; #say "dump(\@retstruct): " . dump(@retstruct);
+	my @retcases = @{ $dirfiles{retcases} }; say TOSHELL "dumpINREPORT::report(\@retcases): " . dump(@retcases); 
+	my @retstruct = @{ $dirfiles{retstruct} }; say TOSHELL "dump(\@retstruct): " . dump(@retstruct);
 	my @repcases = @{ $dirfiles{repcases} };
 	my @repstruct = @{ $dirfiles{repstruct} };
 	my @mergecases = @{ $dirfiles{mergecases} };
 	my @mergestruct = @{ $dirfiles{mergestruct} };
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
-	my %notecases = %{ $dirfiles{notecases} }; 
+	my %notecases = %{ $dirfiles{notecases} }; say TOSHELL "dump(\%notecases): " . dump(%notecases);
 	
 	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
 	my $morphblock = $dirfiles{morphblock};
 	my $simlist = $dirfiles{simlist}; #say "dump(\$simlist): " . dump($simlist);
 	my $simblock = $dirfiles{simblock};
-	my $retlist = $dirfiles{retlist};
+	my $retlist = $dirfiles{retlist}; say TOSHELL "dumpINREPORT::report(\$retlist): " . dump($retlist); 
 	my $retblock = $dirfiles{retblock};
 	my $replist = $dirfiles{replist};
 	my $repblock = $dirfiles{repblock};
@@ -568,9 +586,11 @@ sub report # This function retrieves the results of interest from the texts file
 		#say "THEMEREPORTS::report: " . dump (@themereports);
 		#say TOSHELL "THEMEREPORTS::report: " . dump (@themereports);
 		
-		open( REPLIST, ">>$replist" ) or die;
-		open( REPBLOCK, ">>$repblock" ) or die;
-		$repfile = "$file-report-$countcase-$countblock.txt";
+		open( REPLIST, ">>$replist" ) or die; say TOSHELL "dump---(\$replist): " . dump($replist) . "\n\n";  
+		open( REPBLOCK, ">>$repblock" ) or die; say TOSHELL "dump---(\$repblock): " . dump($repblock) . "\n\n";
+		
+		$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOSHELL "dump---(\$repfile): " . dump($repfile) . "\n\n";
+		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
 		push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
 		say REPBLOCK "$repfile";
@@ -580,43 +600,60 @@ sub report # This function retrieves the results of interest from the texts file
 			say REPLIST "$repfile";
 		}
 
-		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
+		#open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
+		
+		say TOSHELL "dump---(\@notecases): " . dump(@notecases) . "\n\n";  
 		
 		foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ] } )
 		{
-			%retitem = %ret_ref;
-			my $retfile = $retitem{retfile};
-			my $reporttitle = $retitem{reporttitle};
-			my $themereport = $retitem{themereport};
-			my $semaphorego = $retitem{semaphorego};
-			my $semaphorestop = $retitem{semaphorestop};
-			my $textpattern = $retitem{textpattern};
+			%retitem = %$ret_ref; say TOSHELL "dump---(\%retitem): " . dump(%retitem) . "\n\n";  
+			my $retfile = $retitem{retfile}; say TOSHELL "dump---(\$retfile): " . dump($retfile) . "\n\n";  
+			my $reporttitle = $retitem{reporttitle}; say TOSHELL "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
+			my $themereport = $retitem{themereport}; say TOSHELL "dump---(\$themereport): " . dump($themereport) . "\n\n";  
+			my $semaphorego = $retitem{semaphorego}; say TOSHELL "dump---(\$semaphorego): " . dump($semaphorego) . "\n\n";  
+			my $semaphorestop = $retitem{semaphorestop}; say TOSHELL "dump---(\$semaphorestop): " . dump($semaphorestop) . "\n\n";  
+			my $textpattern = $retitem{textpattern}; say TOSHELL "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
 			my $semaphore;
-			open( RETFILE, $retfile ) or die;
-			my @lines = <RETFILE>;
-			foreach my $line (@lines)
+			
+			
+			
+			
+			if ( -e $retfile )
+			#if ( not ( eval ( $skipreport ) ) )
 			{
-				if ( ( not ( $semaphorego ) ) or ( $line =~ m/^$semaphorego/ ) )
+
+				open( RETFILE, "$retfile" ) or die;
+				my @lines = <RETFILE>;
+				close RETFILE;
+				foreach my $line (@lines)
 				{
-					$semaphore = "on";
-				}
-				if ( $line =~ m/^$semaphorestop/ )
-				{
-					$semaphore = "off";
-				}
-				if ( $line =~ m/^$textpattern/ )
-				{
-					push ( @{ $linecontent[ $countinstance ] }, $line );
+					$line =~ s/^\s+//;
+					chomp $line;
+					$line = $line . " ";
+					say "\$line: $line";
+					if ( ( not ( $semaphorego ) ) or ( $line =~ m/^$semaphorego/ ) )
+					{
+						$semaphore = "on";
+					}
+					elsif ( $line =~ m/^$semaphorestop/ )
+					{
+						$semaphore = "off";
+					}
+					if ( ( $line =~ m/^$textpattern/ ) and ( $semaphore eq "on" ) )
+					{
+						print "HIT! "; say $line;
+						push ( @{ $linecontent[ $countinstance ] }, $line );
+						print REPFILE $retfile . " " . $line;
+					}
 				}
 			}
-			close RETFILE;
+			
 		}
-		print REPFILE @{ $linecontent[ $countinstance ] }; 
+		#print REPFILE "\n";
+		push ( @{ $mergestruct[$countcase][$countblock] }, @{ $linecontent[ $countinstance ] } ); say TOSHELL "\@mergestruct: " . dump(@mergestruct); 
 		$countinstance++;
 	}
 	
-	push ( @{ $mergestruct[$countcase][$countblock] }, @repfilemem ); say TOSHELL "\@mergestruct: " . dump(@mergestruct);
-	
 	#if ( @repfilemem ~~ @mergecases ) 
 	#{ 
 	#	push ( @mergecases,  @repfilemem );
